.. currentmodule:: xrtpy

.. _glossary:

********
Glossary
********

.. glossary::
   :sorted:

   DN
      Data number (DN) per unit.

   Contamination (related to the XRT)
      Contamination refers to the accumulation of contaminating material on the XRT CCD and focal plane filters (FPFs), which results in a decrease in sensitivity.
      Refer to Section 2.5.3 `Contamination` in the `SolarSoft XRT Analysis Guide`_ in the `SolarSoft XRT Analysis Guide`_ for
      more information about the XRT contamination.

   Temperature response
      Temperature response refers to the instrument's temperature response function for a specific filter channel. Units measured in
      DN cm\ :sup:`5` s\ :sup:`−1` pix\ :sup:`-1`\ .

   Solar-Emission-Spectra
      Solar emission spectra are a collection of plasma emission spectra corresponding to different temperatures. They provide information about the emitted radiation at various temperatures.

.. _SolarSoft XRT Analysis Guide: https://xrt.cfa.harvard.edu/resources/documents/XAG/XAG.pdf
